/* 
 *	HTE Editor
 *	htinfo.h
 *
 *	Copyright (C) 1999-2002 Stefan Weyergraf (stefan@weyergraf.de)
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2 as
 *	published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __HTINFO_H__
#define __HTINFO_H__

#define ht_url "http://hte.sourceforge.net"

#define ht_name "ht"
#define ht_version "0.7.3"

#define ht_author1 "Stefan Weyergraf"
#define ht_mail1 "stefan@weyergraf.de"
#define ht_copyright1 "(c) 1999-2003 "ht_author1", "ht_mail1

#define ht_author2 "Sebastian Biallas"
#define ht_mail2 "sb@biallas.net"
#define ht_copyright2 "(c) 1999-2003 "ht_author2", "ht_mail2

#endif /* !__HTINFO_H__ */
